@@ -116,7 +116,7 @@ class messages(object):
 
 
 def strtime(t):
-    return time.strftime('%F %H:%M:%S', time.localtime(int(t)))
+    return time.strftime('%FT%H:%M:%SZ', time.gmtime(int(t)))
 
 
 class objects(messages):
@@ -165,6 +165,21 @@ class objects(messages):
                 del self.db[obj_id]
 
 
+class liveobjects(messages):
+    '''
+    prototype
+
+    Like objects(), but the objects are "live":
+    - object is returned as soon as it is "born"
+    - fields update as soon as message is received
+    - field update events are hookable
+
+    The blocking consumer is fine for "passive" objects.
+    For publishing this needs to be done asynchronously.
+    '''
+    pass
+
+
 def findkey(d, key):
     "Find all occurrences of <key> in dict <d> and its contents"
     if isinstance(d, dict):
